==> koshoten.net-2.1.2.tar.gz: koshoten-net/admin/includes/languages/japanese/products_uploader.php <==
<?php
/*
  products_uploader.php
  2003/12/2
ǽ2005/7/26

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'ʥǡ');

define('ERROR_CATALOG_UPLOAD_DIRECTORY_NOT_WRITEABLE', '顼: åץǥ쥯ȥ˽񤭹ߤǤޤ: ' . DIR_FS_UPLOAD);
define('ERROR_CATALOG_UPLOAD_DIRECTORY_DOES_NOT_EXIST', '顼: åץǥ쥯ȥ꤬¸ߤޤ: ' . DIR_FS_UPLOAD);
define('ERROR_UPLOAD_CONFIGFILE_DOSE_NOT_EXIST', '顼: åץե뤬¸ߤޤ: ' . FILENAME_UPLOAD_CONFIG);
define('ERROR_DOWNLOAD_CONFIGFILE_DOSE_NOT_EXIST', '顼: ե뤬¸ߤޤ: ' . FILENAME_DOWNLOAD_CONFIG);
define('ERROR_UPLOADFILE_DOES_NOT_EXIST', '顼: åץɥեλ꤬ޤ');
define('ERROR_UPLOAD_TEMPFILE_DOES_NOT_EXIST', '顼: åץɥեΥåλƤޤ');

define('ERROR_UPLOAD_CONFIG_COLUMN_IS_EMPTY', '顼: ǡޤ');
define('ERROR_UPLOAD_CONFIG_SORT_ORDER_DUPLICATE', '顼: ¤ӽ˽ʣޤ');
define('ERROR_UPLOAD_CONFIG_ID_DUPLICATE', '顼: åץɹܤ˽ʣޤ');
define('ERROR_UPLOAD_DATA_DOES_NOT_EXIST', '顼: åץоݤΥǡǤϤޤ');
define('ERROR_UPLOAD_FIELD_DOES_NOT_EXIST', '顼: åץоݤΥեɤ¸ߤޤ');
define('ERROR_UPLOAD_FIELD_IS_REQUIRED', '顼: ɬܹܤɬܥå⤷ϽͤåȤƤޤ');

define('ERROR_DOWNLOAD_CONFIG_COLUMN_IS_EMPTY', '顼: ǡޤ');
define('ERROR_DOWNLOAD_CONFIG_SORT_ORDER_DUPLICATE', '顼: ¤ӽ˽ʣޤ');
define('ERROR_DOWNLOAD_CONFIG_ID_DUPLICATE', '顼: ɹܤ˽ʣޤ');

define('ERROR_UPLOAD_DATA_IS_REQUIRED', '顼: ɬܹܤ˥ǡäƤޤ');
define('ERROR_UPLOAD_DATA_IS_SHORTAGE', '顼: ­Ƥޤ­ȾѴ = ');
define('ERROR_UPLOAD_DATA_IS_OVERFLOW', '顼: ĶᤷƤޤĶȾѴ = ');
define('ERROR_UPLOAD_DATA_IS_NOT_NUMERIC', '顼: ͹ܤ˿ͰʳϤäƤޤ = ');
define('ERROR_UPLOAD_DATA_IS_NOT_DATE', '顼: չܤ0000-00-00ηˤʤäƤʤդǤϤޤ = ');
define('ERROR_UPLOAD_DATA_DOSE_NOT_EXIST', '顼: ꤷ¤ӽ˥ǡޤ');
define('ERROR_UPLOAD_CATEGORY_DOES_NOT_EXIST', '顼: ϿƤʤƥ꡼Ǥ');
define('ERROR_UPLOAD_MANUFACTURER_DOES_NOT_EXIST', '顼: ϿƤʤ' . KN_CFG_USE_MANUFACTURERS . 'Ǥ');

define('SUCCESS_UPLOAD_CONFIG_UPDATED', ': ե뤬ޤ');
define('SUCCESS_DOWNLOAD_CONFIG_UPDATED', ': ե뤬ޤ');

define('TABLE_HEADING_CONFIG_NO', 'No.');
define('TABLE_HEADING_CONFIG_NAME', '̾(ơ֥̾ : ե̾)');
define('TABLE_HEADING_CONFIG_SORT_ORDER', '¤ӽ');
define('TABLE_HEADING_CONFIG_SELECT', 'ˡ');
define('TABLE_HEADING_CONFIG_DEFAULT', '');
define('TABLE_HEADING_CONFIG_MIN', 'Ǿ');
define('TABLE_HEADING_CONFIG_MAX', '');
define('TABLE_HEADING_CONFIG_REQUIRED', 'ɬܹ');
define('TABLE_HEADING_CONFIG_ERROR_ROW', '顼');
define('TABLE_HEADING_CONFIG_ERROR_MESSAGE', '顼ͳ');
define('TABLE_HEADING_CONFIG_ERROR_DATA', '顼');

define('TABLE_HEADING_PRODUCTS_COUNT', '');
define('TABLE_HEADING_PRODUCTS_DEACTIVATE_COUNT', 'ڤ');
define('TABLE_HEADING_UPLOAD_DATE', 'Ͽ');
define('TABLE_HEADING_UPLOAD_FILENAME', 'ե̾');
define('TABLE_HEADING_UPFILE_COUNT', 'åץɷ');
define('TABLE_HEADING_OK_COUNT', 'Ͽǽ');
define('TABLE_HEADING_NG_COUNT', 'Ͽǽ');
define('TABLE_HEADING_ERROR_COUNT', '顼');
define('TABLE_HEADING_INSERT_COUNT', 'Ͽ');
define('TABLE_HEADING_UPLOAD_DATA_NO', 'ǡNO.');
define('TABLE_HEADING_UPLOAD_ERRNO', '顼ֹ');
define('TABLE_HEADING_UPLOAD_ERROR_DATA', '顼ǡ');
define('TABLE_HEADING_UPLOAD_ERROR', '顼å');

define('TEXT_ID', 'ID');
define('TEXT_NAME', 'NAME');
define('TEXT_DATA_REQUIRED', 'ɬ');
define('TEXT_DATA_NOT_REQUIRED', '-');

define('TEXT_UPLOAD_FILE', 'åץɥե:');
define('TEXT_CATEGORIES_ID', 'ƥ꡼ID');
define('TEXT_CATEGORIES_NAME', 'ƥ꡼');
define('TEXT_PRODUCTS_STATUS', 'ʥơ');
define('TEXT_PRODUCTS_DATE_AVAILABLE', 'ȯ');
define('TEXT_MANUFACTURERS_ID', KN_CFG_USE_MANUFACTURERS . 'ID');
define('TEXT_PRODUCTS_TAX_CLASS', 'Ǽ');
define('TEXT_PRODUCTS_NAME', '̾');
define('TEXT_PRODUCTS_SUBTITLE', '');
define('TEXT_PRODUCTS_SERIES_TITLE', '꡼̾');
define('TEXT_PRODUCTS_DESCRIPTION', 'ʸ');
define('TEXT_PRODUCTS_DESCRIPTION2', 'ʸ');
define('TEXT_PRODUCTS_AUTHOR', '');
define('TEXT_PRODUCTS_PUBLISHED', 'ǯ');
define('TEXT_PRODUCTS_PUBLISHERS', 'Ǹ');
define('TEXT_PRODUCTS_VOLUME', '');
define('TEXT_PRODUCTS_QUANTITY', '');
define('TEXT_PRODUCTS_MODEL', '');
define('TEXT_PRODUCTS_IMAGE', '');
define('TEXT_PRODUCTS_URL', 'URL');
define('TEXT_PRODUCTS_ISBN', 'ISBN');
define('TEXT_PRODUCTS_PRICE', '');
define('TEXT_PRODUCTS_WEIGHT', '');
define('TEXT_PRODUCTS_MEMO', 'ѥ');
define('TEXT_PRODUCTS_KEYWORDS', '');
define('TEXT_RECOMMENDATION_ORDER', '');
define('TEXT_SORT_ORDER', '¤ӽ');

define('TEXT_NO_DATA', 'оݥǡޤǤ');
define('TEXT_NO_UPLOAD_DATA', 'åץɤǡޤ');
define('TEXT_NO_ERROR', 'åץɥǡ˥顼Ϥޤ');
define('TEXT_NO_UPLOAD_HISTORY', 'åץϤޤ');

define('TEXT_CONFIRM_ERROR_MESSAGES', 'åץɥ顼ȯޤ顼å򤴳ǧ');
define('TEXT_DELETION_BY_UPLOAD_HISTORY', 'åץˤ');
define('TEXT_DELETION_BY_PRODUCTS_MODEL', 'ʤη֤ˤ');
define('TEXT_DELETION_BY_PRODUCTS_STATUS', 'ڤ');
define('TEXT_PRODUCTS_DATA_DOWNLOAD', '');
define('TEXT_ALL_PRODUCTS_DELETION', '');
define('TEXT_DELETE_COUNT', 'оݥǡ%s濫ޤޤ');
define('TEXT_DELETE_PRODUCTS_LIST', 'оݥǡ');
define('TEXT_NOTES_TO_INPUT_PRODUCTS_MODELS', '֤ϣԣɤǵƤ');

define('TEXT_UPLOAD_CONFIRMATION', 'åץɥܥ򲡤ȡåץɥեƤǧޤ');
define('TEXT_UPLOAD_CONFIG_ERROR_NOTICE', '嵭ΤȤꥢåץե˥顼ޤåץեƤ');
define('TEXT_DOWNLOAD_CONFIRMATION', 'ܥ򲡤ȡɥեκϤޤ');
define('TEXT_DOWNLOAD_CONFIG_ERROR_NOTICE', '嵭ΤȤե˥顼ޤեƤ');

define('TEXT_UPLOAD_INSERT', '');
define('TEXT_UPLOAD_REPLACE', '');
define('TEXT_DELETE', '');

define('TEXT_PRODUCTS_PACKAGE_REGISTRATION', 'ʰϿ');
define('TEXT_UPLOAD_CONFIRM_01', 'ƥåףåץɤǧ');
define('TEXT_UPLOAD_CONFIRM_02', 'ƥåףåץɥեƥå');
define('TEXT_UPLOAD_WAS_COMPLETED', '%sΥåץɤλޤ');

define('TEXT_UPFILE_COUNT', 'åץɥǡ');
define('TEXT_UPLOAD_CONFIG', 'åץ');
define('TEXT_UPLOAD_CONFIG_ERROR', 'åץꥨ顼');
define('TEXT_UPFILE_LANGUAGE', 'åץоݸ졧');
define('TEXT_UPLOAD_CONFIRM', 'åץɥեΥå');
define('TEXT_UPLOAD_RESULT', 'åץɷ');

define('TEXT_DOWNLOAD_COUNT', 'ɥǡ');
define('TEXT_DOWNLOAD_CONFIG', '');
define('TEXT_DOWNLOAD_CONFIG_ERROR', 'ꥨ顼');
define('TEXT_DOWNLOAD_LANGUAGE', 'оݸ졧');
define('TEXT_DOWNLOAD_CONFIRM', 'ɥեΥå');
define('TEXT_DOWNLOAD_RESULT', 'ɷ');

define('TEXT_PRODUCTS_PACKAGE_DELETION', 'ʰ');
define('TEXT_DELETE_CONFIRM', 'γǧ');

define('ERROR_INSERT_FAILED', 'ϿǤޤǤ(%s)');
define('ERROR_INSERT_INCOMPLETE', 'ϿԴǤproducts_id=%s(%s)');

define('TEXT_ENCODE_TYPE', 'åץɥեʸ');
define('TEXT_ENCODE_TYPE_SJIS', 'եJIS');
define('TEXT_ENCODE_TYPE_EUC', 'EUC-JP');

define('TEXT_UPLOAD_CONFIG_COLUMN_00', 'ܣ¤ӽ');
define('TEXT_UPLOAD_CONFIG_COLUMN_01', 'ܣǡ̾');
define('TEXT_UPLOAD_CONFIG_COLUMN_03', 'ܣ');
define('TEXT_UPLOAD_CONFIG_COLUMN_04', 'ꣴǾ');
define('TEXT_UPLOAD_CONFIG_COLUMN_05', 'ꣵ');
define('TEXT_UPLOAD_CONFIG_COLUMN_06', 'ꣶɬܥޡ');
?>

==> koshoten.net-2.1.4.tar.gz: koshoten-net/admin/includes/languages/japanese/products_uploader.php <==
<?php
/*
  products_uploader.php
  2003/12/2
ǽ2005/9/24

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/

define('HEADING_TITLE', 'ʰ');

define('ERROR_CATALOG_UPLOAD_DIRECTORY_NOT_WRITEABLE', '顼: åץǥ쥯ȥ˽񤭹ߤǤޤ: ' . DIR_FS_UPLOAD);
define('ERROR_CATALOG_UPLOAD_DIRECTORY_DOES_NOT_EXIST', '顼: åץǥ쥯ȥ꤬¸ߤޤ: ' . DIR_FS_UPLOAD);
define('ERROR_UPLOAD_CONFIGFILE_DOSE_NOT_EXIST', '顼: åץե뤬¸ߤޤ: ' . FILENAME_UPLOAD_CONFIG);
define('ERROR_DOWNLOAD_CONFIGFILE_DOSE_NOT_EXIST', '顼: ե뤬¸ߤޤ: ' . FILENAME_DOWNLOAD_CONFIG);
define('ERROR_UPLOADFILE_DOES_NOT_EXIST', '顼: åץɥեλ꤬ޤ');
define('ERROR_UPLOAD_TEMPFILE_DOES_NOT_EXIST', '顼: åץɥեΥåλƤޤ');

define('ERROR_UPLOAD_CONFIG_COLUMN_IS_EMPTY', '顼: ǡޤ');
define('ERROR_UPLOAD_CONFIG_SORT_ORDER_DUPLICATE', '顼: ¤ӽ˽ʣޤ');
define('ERROR_UPLOAD_CONFIG_ID_DUPLICATE', '顼: åץɹܤ˽ʣޤ');
define('ERROR_UPLOAD_DATA_DOES_NOT_EXIST', '顼: åץоݤΥǡǤϤޤ');
define('ERROR_UPLOAD_FIELD_DOES_NOT_EXIST', '顼: åץоݤΥեɤ¸ߤޤ');
define('ERROR_UPLOAD_FIELD_IS_REQUIRED', '顼: ɬܹܤɬܥå⤷ϽͤåȤƤޤ');

define('ERROR_DOWNLOAD_CONFIG_COLUMN_IS_EMPTY', '顼: ǡޤ');
define('ERROR_DOWNLOAD_CONFIG_SORT_ORDER_DUPLICATE', '顼: ¤ӽ˽ʣޤ');
define('ERROR_DOWNLOAD_CONFIG_ID_DUPLICATE', '顼: ɹܤ˽ʣޤ');

define('ERROR_UPLOAD_DATA_IS_REQUIRED', '顼: ɬܹܤ˥ǡäƤޤ');
define('ERROR_UPLOAD_DATA_IS_SHORTAGE', '顼: ­Ƥޤ­ȾѴ = ');
define('ERROR_UPLOAD_DATA_IS_OVERFLOW', '顼: ĶᤷƤޤĶȾѴ = ');
define('ERROR_UPLOAD_DATA_IS_NOT_NUMERIC', '顼: ͹ܤ˿ͰʳϤäƤޤ = ');
define('ERROR_UPLOAD_DATA_IS_NOT_DATE', '顼: չܤ0000-00-00ηˤʤäƤʤդǤϤޤ = ');
define('ERROR_UPLOAD_DATA_DOSE_NOT_EXIST', '顼: ꤷ¤ӽ˥ǡޤ');
define('ERROR_UPLOAD_CATEGORY_DOES_NOT_EXIST', '顼: ϿƤʤƥ꡼Ǥ');
define('ERROR_UPLOAD_MANUFACTURER_DOES_NOT_EXIST', '顼: ϿƤʤ' . KN_CFG_USE_MANUFACTURERS . 'Ǥ');

define('SUCCESS_UPLOAD_CONFIG_UPDATED', ': ե뤬ޤ');
define('SUCCESS_DOWNLOAD_CONFIG_UPDATED', ': ե뤬ޤ');

define('TABLE_HEADING_CONFIG_NO', 'No.');
define('TABLE_HEADING_CONFIG_NAME', '̾(ơ֥̾ : ե̾)');
define('TABLE_HEADING_CONFIG_SORT_ORDER', '¤ӽ');
define('TABLE_HEADING_CONFIG_SELECT', 'ˡ');
define('TABLE_HEADING_CONFIG_DEFAULT', '');
define('TABLE_HEADING_CONFIG_MIN', 'Ǿ');
define('TABLE_HEADING_CONFIG_MAX', '');
define('TABLE_HEADING_CONFIG_REQUIRED', 'ɬܹ');
define('TABLE_HEADING_CONFIG_ERROR_ROW', '顼');
define('TABLE_HEADING_CONFIG_ERROR_MESSAGE', '顼ͳ');
define('TABLE_HEADING_CONFIG_ERROR_DATA', '顼');

define('TABLE_HEADING_PRODUCTS_COUNT', '');
define('TABLE_HEADING_PRODUCTS_DEACTIVATE_COUNT', 'ڤ');
define('TABLE_HEADING_UPLOAD_DATE', 'Ͽ');
define('TABLE_HEADING_UPLOAD_FILENAME', 'ե̾');
define('TABLE_HEADING_UPFILE_COUNT', 'åץɷ');
define('TABLE_HEADING_OK_COUNT', 'Ͽǽ');
define('TABLE_HEADING_NG_COUNT', 'Ͽǽ');
define('TABLE_HEADING_ERROR_COUNT', '顼');
define('TABLE_HEADING_INSERT_COUNT', 'Ͽ');
define('TABLE_HEADING_UPLOAD_DATA_NO', 'ǡNO.');
define('TABLE_HEADING_UPLOAD_ERRNO', '顼ֹ');
define('TABLE_HEADING_UPLOAD_ERROR_DATA', '顼ǡ');
define('TABLE_HEADING_UPLOAD_ERROR', '顼å');

define('TEXT_ID', 'ID');
define('TEXT_NAME', 'NAME');
define('TEXT_DATA_REQUIRED', 'ɬ');
define('TEXT_DATA_NOT_REQUIRED', '-');

define('TEXT_UPLOAD_FILE', 'åץɥե:');
define('TEXT_CATEGORIES_ID', 'ƥ꡼ID');
define('TEXT_CATEGORIES_NAME', 'ƥ꡼');
define('TEXT_PRODUCTS_STATUS', 'ʥơ');
define('TEXT_PRODUCTS_DATE_AVAILABLE', 'ȯ');
define('TEXT_MANUFACTURERS_ID', KN_CFG_USE_MANUFACTURERS . 'ID');
define('TEXT_PRODUCTS_TAX_CLASS', 'Ǽ');
define('TEXT_PRODUCTS_NAME', '̾');
define('TEXT_PRODUCTS_SUBTITLE', '');
define('TEXT_PRODUCTS_SERIES_TITLE', '꡼̾');
define('TEXT_PRODUCTS_DESCRIPTION', 'ʸ');
define('TEXT_PRODUCTS_DESCRIPTION2', 'ʸ');
define('TEXT_PRODUCTS_AUTHOR', '');
define('TEXT_PRODUCTS_PUBLISHED', 'ǯ');
define('TEXT_PRODUCTS_PUBLISHERS', 'Ǹ');
define('TEXT_PRODUCTS_VOLUME', '');
define('TEXT_PRODUCTS_QUANTITY', '߸˿');
define('TEXT_PRODUCTS_MODEL', '');
define('TEXT_PRODUCTS_IMAGE', '');
define('TEXT_PRODUCTS_URL', 'URL');
define('TEXT_PRODUCTS_ISBN', 'ISBN');
define('TEXT_PRODUCTS_PRICE', '');
define('TEXT_PRODUCTS_WEIGHT', '');
define('TEXT_PRODUCTS_MEMO', 'ѥ');
define('TEXT_PRODUCTS_KEYWORDS', '');
define('TEXT_RECOMMENDATION_ORDER', '');
define('TEXT_SORT_ORDER', '¤ӽ');

define('TEXT_NO_DATA', 'оݥǡޤǤ');
define('TEXT_NO_UPLOAD_DATA', 'åץɤǡޤ');
define('TEXT_NO_ERROR', 'åץɥǡ˥顼Ϥޤ');
define('TEXT_NO_UPLOAD_HISTORY', 'åץϤޤ');

define('TEXT_CONFIRM_ERROR_MESSAGES', 'åץɥ顼ȯޤ顼å򤴳ǧ');
define('TEXT_DELETION_BY_UPLOAD_HISTORY', 'åץˤ');
define('TEXT_DELETION_BY_PRODUCTS_MODEL', 'ɤˤ');
define('TEXT_DELETION_BY_PRODUCTS_STATUS', 'ڤ');
define('TEXT_PRODUCTS_DATA_DOWNLOAD', '');
define('TEXT_ALL_PRODUCTS_DELETION', '');
define('TEXT_DELETE_COUNT', 'оݥǡ%s濫ޤޤ');
define('TEXT_DELETE_PRODUCTS_LIST', 'оݥǡ');
define('TEXT_NOTES_TO_INPUT_PRODUCTS_MODELS', 'ɤϣԣɤǵƤ');

define('TEXT_UPLOAD_CONFIRMATION', 'åץɥܥ򲡤ȡåץɥեƤǧޤ');
define('TEXT_UPLOAD_CONFIG_ERROR_NOTICE', '嵭ΤȤꥢåץե˥顼ޤåץեƤ');
define('TEXT_DOWNLOAD_CONFIRMATION', 'ܥ򲡤ȡɥեκϤޤ');
define('TEXT_DOWNLOAD_CONFIG_ERROR_NOTICE', '嵭ΤȤե˥顼ޤեƤ');

define('TEXT_UPLOAD_INSERT', '');
define('TEXT_UPLOAD_REPLACE', '');
define('TEXT_DELETE', '');

define('TEXT_PRODUCTS_PACKAGE_REGISTRATION', 'ʰϿ');
define('TEXT_UPLOAD_CONFIRM_01', 'ƥåףåץɤǧ');
define('TEXT_UPLOAD_CONFIRM_02', 'ƥåףåץɥեƥå');
define('TEXT_UPLOAD_CONFIRM_03', 'ƥåףϿδλ');
define('TEXT_UPLOAD_WAS_COMPLETED', '%sΥåץɤλޤ');

define('TEXT_UPFILE_COUNT', 'åץɥǡ');
define('TEXT_UPLOAD_CONFIG', 'åץ');
define('TEXT_UPLOAD_CONFIG_ERROR', 'åץꥨ顼');
define('TEXT_UPFILE_LANGUAGE', 'åץоݸ졧');
define('TEXT_USE_PRODUCTS_MODEL_AS_ID', 'ɤID˻ѡ');
define('TEXT_USE_PRODUCTS_MODEL_YES_IGNORE', 'ѤIDʣϿʤ');
define('TEXT_USE_PRODUCTS_MODEL_YES_REPLACE', 'ѤIDʣ֤');
define('TEXT_USE_PRODUCTS_MODEL_NO', 'Ѥʤ');
define('TEXT_UPLOAD_CONFIRM', 'åץɥեΥå');
define('TEXT_UPLOAD_RESULT', 'åץɷ');

define('TEXT_DOWNLOAD_COUNT', 'ɥǡ');
define('TEXT_DOWNLOAD_CONFIG', '');
define('TEXT_DOWNLOAD_CONFIG_ERROR', 'ꥨ顼');
define('TEXT_DOWNLOAD_LANGUAGE', 'оݸ졧');
define('TEXT_DOWNLOAD_CONFIRM', 'ɥեΥå');
define('TEXT_DOWNLOAD_RESULT', 'ɷ');

define('TEXT_PRODUCTS_PACKAGE_DELETION', 'ʰ');
define('TEXT_DELETE_CONFIRM', 'γǧ');

define('ERROR_INSERT_FAILED', 'ϿǤޤǤ(%s)');
define('ERROR_INSERT_INCOMPLETE', 'ϿԴǤproducts_id=%s(%s)');

define('TEXT_ENCODE_TYPE', 'åץɥեʸ');
define('TEXT_ENCODE_TYPE_SJIS', 'եJIS');
define('TEXT_ENCODE_TYPE_EUC', 'EUC-JP');

define('TEXT_UPLOAD_CONFIG_COLUMN_00', 'ܣ¤ӽ');
define('TEXT_UPLOAD_CONFIG_COLUMN_01', 'ܣǡ̾');
define('TEXT_UPLOAD_CONFIG_COLUMN_03', 'ܣ');
define('TEXT_UPLOAD_CONFIG_COLUMN_04', 'ꣴǾ');
define('TEXT_UPLOAD_CONFIG_COLUMN_05', 'ꣵ');
define('TEXT_UPLOAD_CONFIG_COLUMN_06', 'ꣶɬܥޡ');
?>
